Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7551)

Unified Diff: chrome/browser/ui/bookmarks/bookmark_prompt_controller.h

Issue 11364196: Remove TabContents from TabStripModelObserver::ActiveTabChanged. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/bookmarks/bookmark_prompt_controller.h
diff --git a/chrome/browser/ui/bookmarks/bookmark_prompt_controller.h b/chrome/browser/ui/bookmarks/bookmark_prompt_controller.h
index c362abe745d4da003c4f78b84986368dd847d9b7..73aeef61504d60a0404db0d35b2aaf25ea129eec 100644
--- a/chrome/browser/ui/bookmarks/bookmark_prompt_controller.h
+++ b/chrome/browser/ui/bookmarks/bookmark_prompt_controller.h
@@ -59,8 +59,8 @@ class BookmarkPromptController : public chrome::BrowserListObserver,
private:
// TabStripModelObserver
- virtual void ActiveTabChanged(TabContents* old_contents,
- TabContents* new_contents,
+ virtual void ActiveTabChanged(content::WebContents* old_contents,
+ content::WebContents* new_contents,
int index,
bool user_gesture) OVERRIDE;
@@ -85,9 +85,9 @@ class BookmarkPromptController : public chrome::BrowserListObserver,
// Set current active browser cache to |browser|. |browser| can be null.
void SetBrowser(Browser* browser);
// Set current active WebContents cache from |tab_contents|. |tab_contents|
// can be null.
- void SetWebContents(TabContents* tab_contents);
+ void SetWebContents(content::WebContents* web_contents);
// Current active browser cache which we will display the prompt on it.
Browser* browser_;
@@ -85,9 +85,9 @@ class BookmarkPromptController : public chrome::BrowserListObserver,
// Set current active browser cache to |browser|. |browser| can be null.
void SetBrowser(Browser* browser);
- // Set current active WebContents cache from |tab_contents|. |tab_contents|
+ // Set current active WebContents cache from |web_contents|. |web_contents|
// can be null.

Powered by Google App Engine
This is Rietveld 408576698